Lua_FairyListWindow = class("Lua_FairyListWindow", Lua_Window);
function Lua_FairyListWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_FairyListWindow";
	self.showClose = false;
	self.isClickClose = true;
	self.blackAlpha = 0.1;
end

function Lua_FairyListWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.bg = UICreate.createUIAtlasImage(self.content, "common_atlas_2", "ui_common_tips_bg", 399, -55, 358, 263);

	local arr = DataCenter.fairyData.fairyList;
	self.fairyArr = Array();
	for i = 1, arr:getSize() do
		if arr[i].isShow then
			if arr[i].show_lvl ~= nil then
				if DataCenter.roleData.level >= arr[i].show_lvl then
					self.fairyArr:add(arr[i]);
				end
			else
				self.fairyArr:add(arr[i]);
			end
		end
	end
	self.fairyArr:sort("index", false);

	self.dragList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 294, 197));
	self.dragList:setListCell(Lua_FairyItem, 90, 294, 1);
	self.dragList:setLocation(399, -53, 0);
	self.dragList:setLuaArrayData(self.fairyArr, true);

	-- Lua_WindowUtil.openWin("Lua_ShopWindow", nil, {openIdx = 2, itemID = 207100101,isShowEffectInFirst = true});
	-- Lua_WindowUtil.openWin("Lua_TransWindow", WinParam.ACTION_OPEN, 1);

	self:addLuaEvent("FAIRY_PANEL_UPDATE", self, self.updatePanel);
	self:addLuaEvent("ON_FAIRY_ITEM_CLICK", self, self.onItemClick);
	Lua_ProxyManager.getProxy("Lua_FairyProxy"):sFairyInfo();
end

function Lua_FairyListWindow:updatePanel()
	local curShowFairy;
	local itemList;
	local noFairyArr = Array();
	local hasFairyArr = Array();
	local sorArr = Array();
	for i = 1, self.fairyArr:getSize() do
		if self.fairyArr[i].isEquiped == true then
			curShowFairy = self.fairyArr[i];
		else
			itemList = DataCenter.packData:getBagType(2):getItemsById(self.fairyArr[i].itemId);
			if itemList == nil or itemList:getSize() == 0 then
				noFairyArr:add(self.fairyArr[i])
			else
				hasFairyArr:add(self.fairyArr[i]);
			end
		end
	end

	if curShowFairy ~= nil then
		sorArr:add(curShowFairy)
	end

	for i = 1, hasFairyArr:getSize() do
		sorArr:add(hasFairyArr[i])
	end

	for i = 1, noFairyArr:getSize() do
		sorArr:add(noFairyArr[i])
	end
	self.dragList:setLuaArrayData(sorArr, true);
end

function Lua_FairyListWindow:onItemClick(itemInfo)
	if itemInfo.isEquiped == false then
		local itemList = DataCenter.packData:getBagType(2):getItemsById(itemInfo.itemId);
		if itemList == nil or itemList:getSize() == 0 then
			-- 精灵未激活
			self:openPurchaseWin(itemInfo, 3);
		else
			local index = 1;
			for i = 1, itemList:getSize() do
				local tempTime = itemList[i].timeOut - DataCenter.roleData.serverTime;
				if tempTime > 0 then
					index = i;
				end

				if itemList[i].fairyVo.isUsed == 1 then
					local leftTime = itemList[i].fairyVo.expireTimes - DataCenter.roleData.serverTime;
					if leftTime > 0 then
						index = i;
					end
				elseif index == 1 then
					index = i;
				end
			end

			local leftTime = itemList[index].timeOut - DataCenter.roleData.serverTime;
			if tonumber(itemList[index].timeOut) == 0 or leftTime > 0 then
				Lua_ProxyManager.getProxy("Lua_FairyProxy"):sPutOnFairy(itemList[index]);
			else
				self:openPurchaseWin(itemList[index], 2);
			end
		end
	end
	self:hide();
end

function Lua_FairyListWindow:openPurchaseWin(data, type)
	Lua_WindowUtil.openWin("Lua_FairyExpireWindow", WinParam.ACTION_OPEN, {fairyPackItemData = data, winType = type});
end

function Lua_FairyListWindow:dispose()
	if self.dragList ~= nil then
		self.dragList:dispose();
		self.dragList = nil;
	end

	self:superCall("dispose");
end





--------------------------------------------------





Lua_FairyItem = class("Lua_FairyItem", Lua_ListCell);
function Lua_FairyItem:ctor(p)
	self:superCall("ctor", p, "FairyItem_skin");
end

function Lua_FairyItem:buildShowItem()
	self:superCall("buildShowItem");

	self.mask.alpha = 0.5;
	self.mask:setEnable(false);

	self.itemImg = Lua_ToolImage.new(self.content);
	self.itemImg:setDepth(1);
	self.itemImg:setScale(0.8, 0.8, 0.8);
	self.itemImg:setLocation(-101.5, 0, 0);
end

function Lua_FairyItem:setData(data)
	self._data = data
	if data == nil then
		return;
	end
	self.itemImg.data = data.toolVo;
	self.nameTxt.text = data.toolVo.colorName;
	self.isEquipTxt:setLocation(self.nameTxt.mainContent.transform.localPosition.x + self.nameTxt.width, self.nameTxt.mainContent.transform.localPosition.y, 0);

	Lua_CommonUtil.removeTimer(self, self.updateLeftTime);
	if data.isEquiped then
		local equipedfairyInfo = DataCenter.fairyData.equipedfairyInfo;
		self:updateLeftTime(equipedfairyInfo);
		Lua_CommonUtil.addTimer("FairyCountDown", 0.5, self, self.updateLeftTime, equipedfairyInfo);
	else
		local itemList = DataCenter.packData:getBagType(2):getItemsById(data.itemId);
		if itemList == nil or itemList:getSize() == 0 then
			self.mask:setEnable(true);
			self.leftTimeTxt.text = LanUtil.getValue(123505);
		else
			local tempTime;
			local index = 1;
			for i = 1, itemList:getSize() do
				tempTime = itemList[i].timeOut - DataCenter.roleData.serverTime;
				if tempTime >= 0 or itemList[i].timeOut == 0 then
					index = i;
				end
			end
			self:updateLeftTime(itemList[index].fairyVo);
			Lua_CommonUtil.addTimer("FairyCountDown", 0.5, self, self.updateLeftTime, itemList[index].fairyVo);
		end
	end
	self.isEquipTxt:setEnable(data.isEquiped);
end

function Lua_FairyItem:updateLeftTime(fairyVo)
	local timeOut = fairyVo.expireTimes;
	if tonumber(timeOut) == 0 then
		self.leftTimeTxt.text = TimeTransform.getInstance():transSeconds1(fairyVo.validTimes, true);
		Lua_CommonUtil.removeTimer(self, self.updateLeftTime);
		return;
	end

	local leftTime = timeOut - DataCenter.roleData.serverTime;
	if leftTime > 0 then
		self.leftTimeTxt.text = TimeTransform.getInstance():transSeconds1(leftTime, true);
	else
		self.leftTimeTxt.text = LanUtil.getValue(110873);
	end
end

function Lua_FairyItem:onPlayerSoundClick(go)
	Lua_MsgUtil.callFunc("ON_FAIRY_ITEM_CLICK", self._data)
end

function Lua_FairyItem:dispose(go)
	if self.itemImg ~= nil then
		self.itemImg:dispose();
		self.itemImg = nil;
	end
	self._data = nil;
	Lua_CommonUtil.removeTimer(self, self.updateLeftTime);

	self:superCall("dispose");
end